@@ -1,8 +1,8 @@
 //! Expression parsing and analysis.
 
-use anyhow::{anyhow, Result};
+use anyhow::{Result, anyhow};
 use itertools::Itertools;
-use pest::{iterators::Pair, Parser};
+use pest::{Parser, iterators::Pair};
 use pest_derive::Parser;
 
 /// A parser for GitHub Actions' expression language.
@@ -44,7 +44,7 @@ impl<'src> Context<'src> {
         {
             match (parent, child) {
                 (Expr::Identifier(parent), Expr::Identifier(child)) => {
-                    if !parent.eq_ignore_ascii_case(child) {
+                    if parent != child {
                         return false;
                     }
                 }
@@ -62,9 +62,7 @@ impl<'src> Context<'src> {
     /// Returns the tail of the context if the head matches the given string.
     pub(crate) fn pop_if(&self, head: &str) -> Option<&str> {
         match self.components().first()? {
-            Expr::Identifier(ident) if ident.eq_ignore_ascii_case(head) => {
-                Some(self.raw.split_once('.')?.1)
-            }
+            Expr::Identifier(ident) if ident == head => Some(self.raw.split_once('.')?.1),
             _ => None,
         }
     }
@@ -95,6 +93,21 @@ impl PartialEq<str> for Context<'_> {
     }
 }
 
+#[derive(Debug)]
+pub(crate) struct Identifier<'src>(&'src str);
+
+impl PartialEq for Identifier<'_> {
+    fn eq(&self, other: &Self) -> bool {
+        self.0.eq_ignore_ascii_case(other.0)
+    }
+}
+
+impl PartialEq<str> for Identifier<'_> {
+    fn eq(&self, other: &str) -> bool {
+        self.0.eq_ignore_ascii_case(other)
+    }
+}
+
 #[derive(Debug, PartialEq)]
 pub(crate) enum BinOp {
     And,
@@ -131,7 +144,7 @@ pub(crate) enum Expr<'src> {
         args: Vec<Expr<'src>>,
     },
     /// A context identifier component, e.g. `github` in `github.actor`.
-    Identifier(&'src str),
+    Identifier(Identifier<'src>),
     /// A context index component, e.g. `[0]` in `foo[0]`.
     Index(Box<Expr<'src>>),
     /// A full context reference.
@@ -153,7 +166,7 @@ impl<'src> Expr<'src> {
     }
 
     pub(crate) fn ident(i: &'src str) -> Self {
-        Self::Identifier(i)
+        Self::Identifier(Identifier(i))
     }
 
     pub(crate) fn context(r: &'src str, components: impl Into<Vec<Expr<'src>>>) -> Self {
@@ -580,33 +593,19 @@ mod tests {
                 "foo.bar.baz",
                 Expr::context(
                     "foo.bar.baz",
-                    [Expr::ident("foo"), Expr::ident("bar"), Expr::ident("baz")]
-                )
+                    [Expr::ident("foo"), Expr::ident("bar"), Expr::ident("baz")],
+                ),
             ),
             (
                 "foo.bar.baz[1][2]",
                 Expr::context(
                     "foo.bar.baz[1][2]",
                     [
-                        Expr::ident(
-                            "foo",
-                        ),
-                        Expr::ident(
-                            "bar",
-                        ),
-                        Expr::ident(
-                            "baz",
-                        ),
-                        Expr::Index(
-                            Expr::Number(
-                                1.0,
-                            ).into(),
-                        ),
-                        Expr::Index(
-                            Expr::Number(
-                                2.0,
-                            ).into(),
-                        ),
+                        Expr::ident("foo"),
+                        Expr::ident("bar"),
+                        Expr::ident("baz"),
+                        Expr::Index(Expr::Number(1.0).into()),
+                        Expr::Index(Expr::Number(2.0).into()),
                     ],
                 ),
             ),
@@ -615,18 +614,10 @@ mod tests {
                 Expr::context(
                     "foo.bar.baz[*]",
                     [
-                        Expr::ident(
-                            "foo",
-                        ),
-                        Expr::ident(
-                            "bar",
-                        ),
-                        Expr::ident(
-                            "baz",
-                        ),
-                        Expr::Index(
-                            Expr::Star.into(),
-                        ),
+                        Expr::ident("foo"),
+                        Expr::ident("bar"),
+                        Expr::ident("baz"),
+                        Expr::Index(Expr::Star.into()),
                     ],
                 ),
             ),
@@ -635,13 +626,9 @@ mod tests {
                 Expr::context(
                     "vegetables.*.ediblePortions",
                     vec![
-                        Expr::ident(
-                            "vegetables",
-                        ),
+                        Expr::ident("vegetables"),
                         Expr::Star,
-                        Expr::ident(
-                            "ediblePortions",
-                        ),
+                        Expr::ident("ediblePortions"),
                     ],
                 ),
             ),
@@ -654,20 +641,20 @@ mod tests {
                         lhs: Expr::BinOp {
                             lhs: Expr::context(
                                 "github.ref",
-                                [
-                                    Expr::ident("github"),
-                                    Expr::ident("ref"),
-                                ],
-                            ).into(),
+                                [Expr::ident("github"), Expr::ident("ref")],
+                            )
+                            .into(),
                             op: BinOp::Eq,
                             rhs: Expr::string("refs/heads/main"),
-                        }.into(),
+                        }
+                        .into(),
                         op: BinOp::And,
                         rhs: Expr::string("value_for_main_branch"),
-                    }.into(),
+                    }
+                    .into(),
                     op: BinOp::Or,
                     rhs: Expr::string("value_for_other_branches"),
-                }
+                },
             ),
             (
                 "(true || false) == true",
@@ -675,11 +662,12 @@ mod tests {
                     lhs: Expr::BinOp {
                         lhs: Expr::Boolean(true).into(),
                         op: BinOp::Or,
-                        rhs: Expr::Boolean(false).into()
-                    }.into(),
+                        rhs: Expr::Boolean(false).into(),
+                    }
+                    .into(),
                     op: BinOp::Eq,
-                    rhs: Expr::Boolean(true).into()
-                }
+                    rhs: Expr::Boolean(true).into(),
+                },
             ),
             (
                 "!(!true || false)",
@@ -688,11 +676,14 @@ mod tests {
                     expr: Expr::BinOp {
                         lhs: Expr::UnOp {
                             op: UnOp::Not,
-                            expr: Expr::Boolean(true).into()
-                        }.into(),
-                    op: BinOp::Or, rhs: Expr::Boolean(false).into()
-                    }.into()
-                }
+                            expr: Expr::Boolean(true).into(),
+                        }
+                        .into(),
+                        op: BinOp::Or,
+                        rhs: Expr::Boolean(false).into(),
+                    }
+                    .into(),
+                },
             ),
         ];
 
