@@ -131,7 +131,7 @@ impl Workflow {
             annotation: "this workflow".to_string(),
             link: None,
             route: Route::new(),
-            primary: false,
+            kind: Default::default(),
         }
     }
 
@@ -777,7 +777,7 @@ impl Action {
             annotation: "this action".to_string(),
             link: None,
             route: Route::new(),
-            primary: false,
+            kind: Default::default(),
         }
     }
 
